/*
 * Gateway for Wireless temperature and humidity sensors. Works with WT450H sensors and WS2015H display unit.
 *
 * NTP routines. Requires Ethernet-shield.
 *
 * v0.1
 * Jaakko Ala-Paavola
 * 2011-02-27
 */

#if ETHERNET

unsigned long epoch( unsigned long ntp_time )
{
  unsigned long epoch = 0;
  if (ntp_time) 
  {
     const unsigned long seventyYears = 2208988800UL;     
    // subtract seventy years:
     epoch = ntp_time - seventyYears;    
  }  
  return epoch;
}

unsigned long receiveNTPtime()
{
  unsigned long secsSince1900 = 0;
  
  if ( Udp.available() ) {  
    Udp.readPacket(packetBuffer,NTP_PACKET_SIZE);  // read the packet into the buffer

    //the timestamp starts at byte 40 of the received packet and is four bytes,
    // or two words, long. First, esxtract the two words:

    unsigned long highWord = word(packetBuffer[40], packetBuffer[41]);
    unsigned long lowWord = word(packetBuffer[42], packetBuffer[43]);  
    // combine the four bytes (two words) into a long integer
    // this is NTP time (seconds since Jan 1 1900):
    secsSince1900 = highWord << 16 | lowWord; 

  }
  return secsSince1900;
}

// send an NTP request to the time server at the given address 
unsigned long sendNTPpacket(byte *address)
{
  // set all bytes in the buffer to 0
  memset(packetBuffer, 0, NTP_PACKET_SIZE); 
  // Initialize values needed to form NTP request
  // (see URL above for details on the packets)
  packetBuffer[0] = 0b11100011;   // LI, Version, Mode
  packetBuffer[1] = 0;     // Stratum, or type of clock
  packetBuffer[2] = 6;     // Polling Interval
  packetBuffer[3] = 0xEC;  // Peer Clock Precision
  // 8 bytes of zero for Root Delay & Root Dispersion
  packetBuffer[12]  = 49; 
  packetBuffer[13]  = 0x4E;
  packetBuffer[14]  = 49;
  packetBuffer[15]  = 52;

  // all NTP fields have been given values, now
  // you can send a packet requesting a timestamp: 		   
  Udp.sendPacket( packetBuffer,NTP_PACKET_SIZE,  address, 123); //NTP requests are to port 123
}

#endif
