/*
 * Gateway for Wireless temperature and humidity sensors. Works with WT450H sensors and WS2015H display unit.
 *
 * Web server routines. Requires Ethernet-shield.
 *
 * v0.1
 * Jaakko Ala-Paavola
 * 2011-02-27
 */
 
#if ETHERNET 
 
void generateWebPage(Client client)
{
    time_t t;
    unsigned char i,j;
    
          client.println("HTTP/1.1 200 OK");
          client.println("Content-Type: text/html");
          client.println();
          client.println("<html><head><title>Wireless measurements</title><meta http-equiv=\"refresh\" content=\"60\">");
          client.println("<body><h3>Measurements:</h3><p>Notice: All times in UTC (GMT time zone).</p>");
 
          if ( !ntpSyncOccurred )
          {
            client.println("<h4><font color=\"red\">Warning: NTP failure, time not synchronized! Clock started from 1.1.1970 00:00</font></h4>");             
          }
 
          client.print("<p>Service started at: ");
          webPrintDate(client,startTime);
          client.print(' ');
          webPrintTime(client,startTime);
          client.println("</p>");
          
          client.print("<p>Page generated at: ");
          t = now();
          webPrintDate(client,t);
          client.print(' ');
          webPrintTime(client,t);
          client.println('</p>.');
          
          client.print("<p>Latest NTP sync occured: ");
          webPrintTime(client, lastSync);
          client.println(" (sync once an hour)</p>");
          
          client.println("<table border=1><tr><td><b>Network</b></td><td><b>Sensor</b></td><td><b>Temp [&deg;C]</b></td><td><b>Min [&deg;C]</b></td><td><b>Max [&deg;C]</b></td><td><b>RH [%]</b></td><td><b>Timestamp</b></td><td><b>Delay [min]</b></td></tr>");
                   
          for (j=0; j<NETWORK_COUNT; j++ )
          {
            for (i=0; i<SENSOR_COUNT; i++) {
              t = measurement[j][i].timestamp;
              if ( t ) {
                client.print("<tr><td>");
                client.print(j,DEC);
                client.print("</td><td>");
                client.print(i,DEC);
                client.print("</td><td>");
#ifdef FLOATING_POINT
                client.print(measurement[j][i].temp,1);
                client.print("</td><td>");
                client.print(measurement[j][i].temp_min,1);
                client.print("</td><td>");
                client.print(measurement[j][i].temp_max,1);
#else
                client.print(measurement[j][i].temp_int,DEC);
                client.print('.');
                client.print(measurement[j][i].temp_dec,DEC);
                client.print("</td><td>");
                client.print(measurement[j][i].min_int,DEC);
                client.print('.');
                client.print(measurement[j][i].min_dec,DEC);
                client.print("</td><td>");
                client.print(measurement[j][i].max_int,DEC);
                client.print('.');
                client.print(measurement[j][i].max_dec,DEC);
#endif                 
                client.print("</td><td>");                
                client.print(measurement[j][i].humidity,DEC);
                client.print("</td><td>");
                webPrintDate(client,measurement[j][i].timestamp);
                client.print(' ');
                webPrintTime(client,measurement[j][i].timestamp);
                client.print("</td><td>");
                client.print((now()-measurement[j][i].timestamp)/60);
                client.println("</tr>");
              }
            }
          }
          client.println("</table>");

          client.println("<p>Min and Max values are counted on a daily basis.</p>");

          client.println("<p>The page will refresh once a minute.</p>");

          client.println("<pre><a href=\"http://ala-paavola.fi/jaakko\">Hardware description</a></pre>");
          
          client.println("</body></html>");
}

void webPrintTime(Client client, time_t t)
{
  client.print(hour(t),DEC);
  client.print(':');
  if ( minute(t) < 10 ) client.print('0');
  client.print(minute(t),DEC);
  client.print(':');
  if ( second(t) < 10 ) client.print('0');
  client.print(second(t),DEC);
}

void webPrintDate(Client client, time_t t)
{
  client.print(year(t),DEC);
  client.print('-');
  if ( month(t) < 10 ) client.print('0');
  client.print(month(t),DEC);
  client.print('-');
  if ( day(t) < 10 ) client.print('0'); 
  client.print(day(t),DEC);
}

#endif
